@@ -51,14 +51,14 @@ class ignition::sensors::MagnetometerSensorPrivate
 
   /// \brief The latest field reading from the sensor, based on the world
   /// field and the sensor's current pose.
-  public: ignition::math::Vector3d localField;
+  public: math::Vector3d localField;
 
   /// \brief Store world magnetic field vector. We assume it is uniform
   /// everywhere in the world, and that it doesn't change during the simulation.
-  public: ignition::math::Vector3d worldField;
+  public: math::Vector3d worldField;
 
   /// \brief World pose of the magnetometer
-  public: ignition::math::Pose3d worldPose;
+  public: math::Pose3d worldPose;
 
   /// \brief Noise added to sensor data
   public: std::map<SensorNoiseType, NoisePtr> noises;
@@ -105,7 +105,7 @@ bool MagnetometerSensor::Load(const sdf::Sensor &_sdf)
     this->SetTopic("/magnetometer");
 
   this->dataPtr->pub =
-      this->dataPtr->node.Advertise<ignition::msgs::Magnetometer>(
+      this->dataPtr->node.Advertise<msgs::Magnetometer>(
       this->Topic());
 
   if (!this->dataPtr->pub)
@@ -149,7 +149,7 @@ bool MagnetometerSensor::Load(sdf::ElementPtr _sdf)
 }
 
 //////////////////////////////////////////////////
-bool MagnetometerSensor::Update(const ignition::common::Time &_now)
+bool MagnetometerSensor::Update(const common::Time &_now)
 {
   IGN_PROFILE("MagnetometerSensor::Update");
   if (!this->dataPtr->initialized)
@@ -168,7 +168,7 @@ bool MagnetometerSensor::Update(const ignition::common::Time &_now)
   msg.mutable_header()->mutable_stamp()->set_nsec(_now.nsec);
   auto frame = msg.mutable_header()->add_data();
   frame->set_key("frame_id");
-  frame->add_value(this->Name());
+  frame->add_value(this->FrameId());
 
   // Apply magnetometer noise after converting to body frame
   if (this->dataPtr->noises.find(MAGNETOMETER_X_NOISE_TESLA) !=
