@@ -204,7 +204,7 @@ bool ThermalCameraSensor::Load(const sdf::Sensor &_sdf)
 
   // Create the thermal image publisher
   this->dataPtr->thermalPub =
-      this->dataPtr->node.Advertise<ignition::msgs::Image>(
+      this->dataPtr->node.Advertise<msgs::Image>(
           this->Topic());
 
   if (!this->dataPtr->thermalPub)
@@ -350,13 +350,13 @@ rendering::ThermalCameraPtr ThermalCameraSensor::ThermalCamera()
 
 /////////////////////////////////////////////////
 common::ConnectionPtr ThermalCameraSensor::ConnectImageCallback(
-    std::function<void(const ignition::msgs::Image &)> _callback)
+    std::function<void(const msgs::Image &)> _callback)
 {
   return this->dataPtr->imageEvent.Connect(_callback);
 }
 
 /////////////////////////////////////////////////
-void ThermalCameraSensor::SetScene(ignition::rendering::ScenePtr _scene)
+void ThermalCameraSensor::SetScene(rendering::ScenePtr _scene)
 {
   std::lock_guard<std::mutex> lock(this->dataPtr->mutex);
   // APIs make it possible for the scene pointer to change
@@ -372,7 +372,7 @@ void ThermalCameraSensor::SetScene(ignition::rendering::ScenePtr _scene)
 }
 
 //////////////////////////////////////////////////
-bool ThermalCameraSensor::Update(const ignition::common::Time &_now)
+bool ThermalCameraSensor::Update(const common::Time &_now)
 {
   IGN_PROFILE("ThermalCameraSensor::Update");
   if (!this->dataPtr->initialized)
@@ -414,7 +414,7 @@ bool ThermalCameraSensor::Update(const ignition::common::Time &_now)
   stamp->set_nsec(_now.nsec);
   auto frame = this->dataPtr->thermalMsg.mutable_header()->add_data();
   frame->set_key("frame_id");
-  frame->add_value(this->Name());
+  frame->add_value(this->FrameId());
 
   std::lock_guard<std::mutex> lock(this->dataPtr->mutex);
   this->dataPtr->thermalMsg.set_data(this->dataPtr->thermalBuffer,
@@ -550,19 +550,19 @@ bool ThermalCameraSensorPrivate::ConvertTemperatureToImage(
 //////////////////////////////////////////////////
 bool ThermalCameraSensorPrivate::SaveImage(const uint16_t *_data,
     unsigned int _width, unsigned int _height,
-    ignition::common::Image::PixelFormatType /*_format*/)
+    common::Image::PixelFormatType /*_format*/)
 {
   // Attempt to create the directory if it doesn't exist
-  if (!ignition::common::isDirectory(this->saveImagePath))
+  if (!common::isDirectory(this->saveImagePath))
   {
-    if (!ignition::common::createDirectories(this->saveImagePath))
+    if (!common::createDirectories(this->saveImagePath))
       return false;
   }
 
   if (_width == 0 || _height == 0)
     return false;
 
-  ignition::common::Image localImage;
+  common::Image localImage;
 
   if (static_cast<int>(_width) != this->imgThermalBufferSize.X() ||
       static_cast<int>(_height) != this->imgThermalBufferSize.Y())
@@ -583,7 +583,7 @@ bool ThermalCameraSensorPrivate::SaveImage(const uint16_t *_data,
   localImage.SetFromData(this->imgThermalBuffer, _width, _height,
       common::Image::RGB_INT8);
   localImage.SavePNG(
-      ignition::common::joinPaths(this->saveImagePath, filename));
+      common::joinPaths(this->saveImagePath, filename));
 
   return true;
 }
